package App::vget;

use warnings;
use strict;


our $VERSION = '0.02';


1;


__END__



=head1 NAME

App::vget - Video downloader

=head1 SYNOPSIS

None.

=head1 DESCRIPTION

This is just a marker package so you can install this distribution from the
CPAN shell.

=head1 TAGS

If you talk about this module in blogs, on del.icio.us or anywhere else,
please use the C<appvget> tag.

=head1 VERSION 
                   
This document describes version 0.02 of L<App::vget>.

=head1 BUGS AND LIMITATIONS

No bugs have been reported.

Please report any bugs or feature requests to
C<<bug-app-vget@rt.cpan.org>>, or through the web interface at
L<http://rt.cpan.org>.

=head1 INSTALLATION

See perlmodinstall for information and options on installing Perl modules.

=head1 AVAILABILITY

The latest version of this module is available from the Comprehensive Perl
Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.

=head1 AUTHOR

Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>

=head1 COPYRIGHT AND LICENSE

Copyright 2007-2008 by Marcel GrE<uuml>nauer

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.


=cut

